<?php
/**
 * Get value from options.
 *
 * @since 1.0.0
 * @param string $key		Option key to get value.
 * @param bool $multisite	Flag to check if it's subsite request.
 * @return mixed
 */
function divi_monk_get( $key, $multisite = false ) {
	if ( is_network_admin() ) {
		return get_site_option( $key );
	} else {
		if ( $multisite && is_multisite() ) {
			return get_site_option( $key );
		}
		return get_option( $key );
	}
}

/**
 * Update value in options.
 *
 * @since 1.0.0
 * @param string $key		Option key to store value.
 * @param mixed $value		Value to be updated.
 * @param bool $multisite	Flag to check if it's subsite request.
 */
function divi_monk_update( $key, $value, $multisite = false ) {
	if ( is_network_admin() ) {
		return update_site_option( $key, $value );
	} else {
		if ( $multisite && is_multisite() ) {
			return update_site_option( $key, $value );
		}
		return update_option( $key, $value );
	}
}

/**
 * Delete value from options.
 *
 * @since 1.0.0
 * @param string $key		Option key to delete value.
 * @param bool $multisite	Flag to check if it's subsite request.
 */
function divi_monk_delete( $key, $multisite = false ) {
	if ( is_network_admin() ) {
		return delete_site_option( $key );
	} else {
		if ( $multisite && is_multisite() ) {
			return delete_site_option( $key );
		}
		return delete_option( $key );
	}
}

/**
 * Get category filters for templates.
 *
 * @since 1.0.0
 * @param string $type		Template type.
 * @return array
 */
function divi_monk_template_categories( $type = 'layout' )
{
    $layout = array(
        'landing'       => esc_html__('Landing', 'divi-monk'),
        'home'          => esc_html__('Home', 'divi-monk'),
        'about'         => esc_html__('About', 'divi-monk'),
        'contact'       => esc_html__('Contact', 'divi-monk'),
        'coming_soon'   => esc_html__('Coming Soon', 'divi-monk'),
        'sales'         => esc_html__('Sales Funnel', 'divi-monk'),
    );

    $section = array();
    $module = array();

    if ( 'layout' == $type ) {
        return $layout;
    }
    if ( 'section' == $type ) {
        return $section;
    }
    if ( 'module' == $type ) {
        return $module;
    }
}

/**
 * Get count of the templates.
 *
 * @since 1.0.0
 * @param string $type		Template type.
 * @param array $data		Template data.
 * @return int
 */
function divi_monk_template_count( $data, $type )
{
	$count = 0;

	if ( ! $data || ! is_array( $data ) || count( $data ) == 0 ) {
        return $count;
    }

	if ( ! $type ) {
        return;
    }

	foreach ( $data as $template ) {
		if ( isset( $template['status'] ) && 'private' == $template['status'] ) {
			continue;
		}
		if ( ! isset( $template['type'] ) || $type != $template['type'] ) {
			continue;
		}
		$count++;
	}

    return $count;
}
