<?php

// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
define( 'DIVI_MONK_SL_URL', 'https://divimonk.com' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

// the name of your product. This should match the download name in EDD exactly
define( 'DIVI_MONK_ITEM_NAME', 'Divi Monk Templates' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

if( ! class_exists( 'EDD_SL_Plugin_Updater' ) ) {
	// load our custom updater
	include( 'EDD_SL_Plugin_Updater.php' );
}

function divi_monk_plugin_updater() {

	// retrieve our license key from the DB
	$license_key = trim( divi_monk_get( '_divi_monk_license_key' ) );

	// setup the updater
	$edd_updater = new EDD_SL_Plugin_Updater( DIVI_MONK_SL_URL, DIVI_MONK_DIR . '/divi-monk.php', array(
			'version' 	=> DIVI_MONK_VER, 					// current version number
			'license' 	=> $license_key, 						// license key (used divi_monk_get above to retrieve from DB)
			'item_name' => DIVI_MONK_ITEM_NAME, 			// name of this plugin
			'author' 	=> 'Divi Monk' 	// author of this plugin
		)
	);

}
add_action( 'admin_init', 'divi_monk_plugin_updater', 0 );

/************************************
* this illustrates how to activate
* a license key
*************************************/

function divi_monk_activate_license() {

	// listen for our activate button to be clicked
	if ( isset( $_POST['divi_monk_license_key'] ) ) {

		// run a quick security check
	 	if( ! isset( $_POST['divi_monk_license_activate_nonce'] ) || ! wp_verify_nonce( $_POST['divi_monk_license_activate_nonce'], '_divi_monk_license_activate_nonce' ) )
			return; // get out if we didn't click the Activate button

		// retrieve the license from the database
		$license = trim( $_POST['divi_monk_license_key'] );

		// data to send in our API request
		$api_params = array(
			'edd_action'=> 'activate_license',
			'license' 	=> $license,
			'item_name' => urlencode( DIVI_MONK_ITEM_NAME ), // the name of our product in EDD
			'url'       => network_home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( DIVI_MONK_SL_URL, array(
			'timeout' 	=> 15,
			'sslverify' => false,
			'body' 		=> $api_params
		) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) )
			return false;

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "valid" or "invalid"

		divi_monk_update( '_divi_monk_license_status', $license_data->license );

	}
}
add_action( 'admin_init', 'divi_monk_activate_license' );

/***********************************************
* Illustrates how to deactivate a license key.
* This will descrease the site count
***********************************************/

function divi_monk_deactivate_license() {

	// listen for our activate button to be clicked
	if( isset( $_POST['divi_monk_license_deactivate'] ) && isset( $_POST['divi_monk_license_key'] ) ) {

		// run a quick security check
	 	if( ! isset( $_POST['divi_monk_license_deactivate_nonce'] ) || ! wp_verify_nonce( $_POST['divi_monk_license_deactivate_nonce'], '_divi_monk_license_deactivate_nonce' ) )
			return; // get out if we didn't click the Activate button

		// retrieve the license from the database
		$license = trim( $_POST['divi_monk_license_key'] );

		// data to send in our API request
		$api_params = array(
			'edd_action'=> 'deactivate_license',
			'license' 	=> $license,
			'item_name' => urlencode( DIVI_MONK_ITEM_NAME ), // the name of our product in EDD
			'url'       => network_home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( DIVI_MONK_SL_URL, array(
			'timeout' 	=> 15,
			'sslverify' => false,
			'body' 		=> $api_params
		) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) )
			return false;

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "deactivated" or "failed"
		if( $license_data->license == 'deactivated' )
			divi_monk_delete( '_divi_monk_license_status', true );

	}
}
add_action( 'admin_init', 'divi_monk_deactivate_license' );

/************************************
* check if
* a license key is still valid
* so this is only needed if we
* want to do something custom
*************************************/

function divi_monk_check_license() {

	$license = divi_monk_get( '_divi_monk_license_key', true );

	if ( ! $license || empty( trim( $license ) ) ) {
		return 'invalid';
	} else {
		$license = trim( $license );
	}

	$api_params = array(
		'edd_action' => 'check_license',
		'license' 	=> $license,
		'item_name' => urlencode( DIVI_MONK_ITEM_NAME ),
		'url'       => network_home_url()
	);

	// Call the custom API.
	$response = wp_remote_post( DIVI_MONK_SL_URL, array(
		'timeout' 	=> 15,
		'sslverify' => false,
		'body' 		=> $api_params
	) );

	if ( is_wp_error( $response ) )
		return false;

	$license_data = json_decode( wp_remote_retrieve_body( $response ) );

	if( $license_data->license == 'valid' ) {
		return 'valid';
		// this license is still valid
	} else {
		return 'invalid';
		// this license is no longer valid
	}
}

 /**
  * Show update message on plugins page
  */
function divi_monk_update_message( $plugin_data, $response ) {
	if ( 'invalid' == divi_monk_check_license() ) {

		$message  = '';
		$message .= '<p style="padding: 5px 10px; margin-top: 10px; background: #d54e21; color: #fff;">';
		$message .= __( '<strong>UPDATE UNAVAILABLE!</strong>', 'divi-monk' );
		$message .= '&nbsp;&nbsp;&nbsp;';
		$message .= __( 'Please activate the license key to enable automatic updates for this plugin.', 'divi-monk' );

		$message .= ' <a href="' . DIVI_MONK_SL_URL . '" target="_blank" style="color: #fff; text-decoration: underline;">';
		$message .= __( 'Buy Now', 'divi-monk' );
		$message .= ' &raquo;</a>';

		$message .= '</p>';

		echo $message;
	}
}
add_action( 'in_plugin_update_message-' . DIVI_MONK_PATH, 'divi_monk_update_message', 1, 2 );
